# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.orders_api import OrdersApi


class TestOrdersApi(unittest.TestCase):
    """OrdersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrdersApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_order(self) -> None:
        """Test case for cancel_order

        Cancel Order
        """
        pass

    def test_create_order(self) -> None:
        """Test case for create_order

        Create order
        """
        pass

    def test_get_order_by_id(self) -> None:
        """Test case for get_order_by_id

        Get Order
        """
        pass

    def test_get_orders(self) -> None:
        """Test case for get_orders

        Get a list of Orders
        """
        pass

    def test_order_cancel_refund(self) -> None:
        """Test case for order_cancel_refund

        Cancel Refund
        """
        pass

    def test_order_refund(self) -> None:
        """Test case for order_refund

        Refund Order
        """
        pass

    def test_orders_create_capture(self) -> None:
        """Test case for orders_create_capture

        Capture Order
        """
        pass

    def test_update_order(self) -> None:
        """Test case for update_order

        Update Order
        """
        pass


if __name__ == '__main__':
    unittest.main()
