# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.payment_methods_api import PaymentMethodsApi


class TestPaymentMethodsApi(unittest.TestCase):
    """PaymentMethodsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PaymentMethodsApi()

    def tearDown(self) -> None:
        pass

    def test_create_customer_payment_methods(self) -> None:
        """Test case for create_customer_payment_methods

        Create Payment Method
        """
        pass

    def test_delete_customer_payment_methods(self) -> None:
        """Test case for delete_customer_payment_methods

        Delete Payment Method
        """
        pass

    def test_get_customer_payment_methods(self) -> None:
        """Test case for get_customer_payment_methods

        Get Payment Methods
        """
        pass

    def test_update_customer_payment_methods(self) -> None:
        """Test case for update_customer_payment_methods

        Update Payment Method
        """
        pass


if __name__ == '__main__':
    unittest.main()
