# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.plans_api import PlansApi


class TestPlansApi(unittest.TestCase):
    """PlansApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PlansApi()

    def tearDown(self) -> None:
        pass

    def test_create_plan(self) -> None:
        """Test case for create_plan

        Create Plan
        """
        pass

    def test_delete_plan(self) -> None:
        """Test case for delete_plan

        Delete Plan
        """
        pass

    def test_get_plan(self) -> None:
        """Test case for get_plan

        Get Plan
        """
        pass

    def test_get_plans(self) -> None:
        """Test case for get_plans

        Get A List of Plans
        """
        pass

    def test_update_plan(self) -> None:
        """Test case for update_plan

        Update Plan
        """
        pass


if __name__ == '__main__':
    unittest.main()
