# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.companies_api import CompaniesApi


class TestCompaniesApi(unittest.TestCase):
    """CompaniesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CompaniesApi()

    def tearDown(self) -> None:
        pass

    def test_create_company(self) -> None:
        """Test case for create_company

        Create Company
        """
        pass

    def test_get_companies(self) -> None:
        """Test case for get_companies

        Get List of Companies
        """
        pass

    def test_get_company(self) -> None:
        """Test case for get_company

        Get Company
        """
        pass

    def test_get_company_documents(self) -> None:
        """Test case for get_company_documents

        Get Company Documents
        """
        pass

    def test_update_company_document(self) -> None:
        """Test case for update_company_document

        Update Company Document
        """
        pass

    def test_upload_company_document(self) -> None:
        """Test case for upload_company_document

        Upload Company Document
        """
        pass


if __name__ == '__main__':
    unittest.main()
