# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.antifraud_api import AntifraudApi


class TestAntifraudApi(unittest.TestCase):
    """AntifraudApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AntifraudApi()

    def tearDown(self) -> None:
        pass

    def test_create_rule_blacklist(self) -> None:
        """Test case for create_rule_blacklist

        Create blacklisted rule
        """
        pass

    def test_create_rule_whitelist(self) -> None:
        """Test case for create_rule_whitelist

        Create whitelisted rule
        """
        pass

    def test_delete_rule_blacklist(self) -> None:
        """Test case for delete_rule_blacklist

        Delete blacklisted rule
        """
        pass

    def test_delete_rule_whitelist(self) -> None:
        """Test case for delete_rule_whitelist

        Delete whitelisted rule
        """
        pass

    def test_get_rule_blacklist(self) -> None:
        """Test case for get_rule_blacklist

        Get list of blacklisted rules
        """
        pass

    def test_get_rule_whitelist(self) -> None:
        """Test case for get_rule_whitelist

        Get a list of whitelisted rules
        """
        pass


if __name__ == '__main__':
    unittest.main()
