# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.payment_link_api import PaymentLinkApi


class TestPaymentLinkApi(unittest.TestCase):
    """PaymentLinkApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PaymentLinkApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_checkout(self) -> None:
        """Test case for cancel_checkout

        Cancel Payment Link
        """
        pass

    def test_create_checkout(self) -> None:
        """Test case for create_checkout

        Create Unique Payment Link
        """
        pass

    def test_email_checkout(self) -> None:
        """Test case for email_checkout

        Send an email
        """
        pass

    def test_get_checkout(self) -> None:
        """Test case for get_checkout

        Get a payment link by ID
        """
        pass

    def test_get_checkouts(self) -> None:
        """Test case for get_checkouts

        Get a list of payment links
        """
        pass

    def test_sms_checkout(self) -> None:
        """Test case for sms_checkout

        Send an sms
        """
        pass


if __name__ == '__main__':
    unittest.main()
