# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.shipping_contacts_api import ShippingContactsApi


class TestShippingContactsApi(unittest.TestCase):
    """ShippingContactsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ShippingContactsApi()

    def tearDown(self) -> None:
        pass

    def test_create_customer_shipping_contacts(self) -> None:
        """Test case for create_customer_shipping_contacts

        Create a shipping contacts
        """
        pass

    def test_delete_customer_shipping_contacts(self) -> None:
        """Test case for delete_customer_shipping_contacts

        Delete shipping contacts
        """
        pass

    def test_update_customer_shipping_contacts(self) -> None:
        """Test case for update_customer_shipping_contacts

        Update shipping contacts
        """
        pass


if __name__ == '__main__':
    unittest.main()
