# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.subscriptions_api import SubscriptionsApi


class TestSubscriptionsApi(unittest.TestCase):
    """SubscriptionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SubscriptionsApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_subscription(self) -> None:
        """Test case for cancel_subscription

        Cancel Subscription [Deprecated]
        """
        pass

    def test_create_subscription(self) -> None:
        """Test case for create_subscription

        Create Subscription [Deprecated]
        """
        pass

    def test_get_subscription(self) -> None:
        """Test case for get_subscription

        Get Subscription [Deprecated]
        """
        pass

    def test_get_subscription_events(self) -> None:
        """Test case for get_subscription_events

        Get Subscription Events [Deprecated]
        """
        pass

    def test_pause_subscription(self) -> None:
        """Test case for pause_subscription

        Pause Subscription [Deprecated]
        """
        pass

    def test_resume_subscription(self) -> None:
        """Test case for resume_subscription

        Resume Subscription [Deprecated]
        """
        pass

    def test_subscription_cancel(self) -> None:
        """Test case for subscription_cancel

        Cancel Subscription
        """
        pass

    def test_subscription_create(self) -> None:
        """Test case for subscription_create

        Create Subscription
        """
        pass

    def test_subscription_events(self) -> None:
        """Test case for subscription_events

        Get Subscription Events
        """
        pass

    def test_subscription_list(self) -> None:
        """Test case for subscription_list

        List Subscriptions
        """
        pass

    def test_subscription_pause(self) -> None:
        """Test case for subscription_pause

        Pause Subscription
        """
        pass

    def test_subscription_resume(self) -> None:
        """Test case for subscription_resume

        Resume Subscription
        """
        pass

    def test_subscription_update(self) -> None:
        """Test case for subscription_update

        Update Subscription
        """
        pass

    def test_subscriptions_get(self) -> None:
        """Test case for subscriptions_get

        Get Subscription
        """
        pass

    def test_subscriptions_retry(self) -> None:
        """Test case for subscriptions_retry

        Retry Failed Payment
        """
        pass

    def test_update_subscription(self) -> None:
        """Test case for update_subscription

        Update Subscription [Deprecated]
        """
        pass


if __name__ == '__main__':
    unittest.main()
