# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.events_api import EventsApi


class TestEventsApi(unittest.TestCase):
    """EventsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EventsApi()

    def tearDown(self) -> None:
        pass

    def test_get_event(self) -> None:
        """Test case for get_event

        Get Event
        """
        pass

    def test_get_events(self) -> None:
        """Test case for get_events

        Get list of Events
        """
        pass

    def test_resend_event(self) -> None:
        """Test case for resend_event

        Resend Event
        """
        pass


if __name__ == '__main__':
    unittest.main()
