# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.charges_api import ChargesApi


class TestChargesApi(unittest.TestCase):
    """ChargesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ChargesApi()

    def tearDown(self) -> None:
        pass

    def test_get_charges(self) -> None:
        """Test case for get_charges

        Get A List of Charges
        """
        pass

    def test_orders_create_charge(self) -> None:
        """Test case for orders_create_charge

        Create charge
        """
        pass

    def test_orders_create_charges(self) -> None:
        """Test case for orders_create_charges

        Create charges
        """
        pass

    def test_update_charge(self) -> None:
        """Test case for update_charge

        Update a charge
        """
        pass


if __name__ == '__main__':
    unittest.main()
